@@ -5,11 +5,8 @@ def interp_heading(heading: np.ndarray,
                    t_series: np.ndarray,
                    t_in: float) -> float:
     """
-    Created by: Tim Stahl
-    Created on: 01.07.2019
-
-    Documentation: Interpolate within a given heading course. (Converts to cos and sin, interpolates and converts back)
-                   WARNING: Relies on small-angle approximation, i.e. the heading series should be tightly spaced.
+    Interpolate within a given heading course. (Converts to cos and sin, interpolates and converts back)
+    WARNING: Relies on small-angle approximation, i.e. the heading series should be tightly spaced.
 
     :param heading:             heading course of original data
     :param t_series:            series of time values (matching the heading course)
